@@ -26,8 +26,8 @@
 class AKONADI_TESTS_EXPORT Akonadi::ChangeRecorderPrivate : public Akonadi::MonitorPrivate
 {
   public:
-    ChangeRecorderPrivate( ChangeRecorder* parent ) :
-      MonitorPrivate( parent ),
+    ChangeRecorderPrivate( MonitorDependeciesFactory *dependenciesFactory_, ChangeRecorder* parent ) :
+      MonitorPrivate( dependenciesFactory_, parent ),
       settings( 0 ),
       enableChangeRecording( true )
     {
@@ -115,8 +115,12 @@ class AKONADI_TESTS_EXPORT Akonadi::ChangeRecorderPrivate : public Akonadi::Moni
       QFile file( changesFileName );
       if ( !file.open( QIODevice::ReadOnly ) )
         return;
+      pendingNotifications = loadFrom( &file );
+    }
 
-      QDataStream stream( &file );
+    QQueue<NotificationMessage> loadFrom( QIODevice *device )
+    {
+      QDataStream stream( device );
       stream.setVersion( QDataStream::Qt_4_6 );
 
       qulonglong size;
@@ -126,6 +130,8 @@ class AKONADI_TESTS_EXPORT Akonadi::ChangeRecorderPrivate : public Akonadi::Moni
       QString remoteId, mimeType;
       QSet<QByteArray> itemParts;
 
+      QQueue<NotificationMessage> list;
+
       stream >> size;
       for ( qulonglong i = 0; i < size; ++i ) {
         NotificationMessage msg;
@@ -151,8 +157,23 @@ class AKONADI_TESTS_EXPORT Akonadi::ChangeRecorderPrivate : public Akonadi::Moni
         msg.setParentDestCollection( parentDestCollection );
         msg.setMimeType( mimeType );
         msg.setItemParts( itemParts );
-        pendingNotifications << msg;
+        list << msg;
       }
+      return list;
+    }
+
+    void addToStream( QDataStream &stream, const NotificationMessage &msg )
+    {
+        stream << msg.sessionId();
+        stream << msg.type();
+        stream << msg.operation();
+        stream << msg.uid();
+        stream << msg.remoteId();
+        stream << msg.resource();
+        stream << msg.parentCollection();
+        stream << msg.parentDestCollection();
+        stream << msg.mimeType();
+        stream << msg.itemParts();
     }
 
     void saveNotifications()
@@ -170,28 +191,26 @@ class AKONADI_TESTS_EXPORT Akonadi::ChangeRecorderPrivate : public Akonadi::Moni
         qWarning() << "could not save notifications to file " << file.fileName();
         return;
       }
+      saveTo(&file);
+    }
 
-      QDataStream stream( &file );
+    void saveTo( QIODevice *device )
+    {
+
+      QDataStream stream( device );
       stream.setVersion( QDataStream::Qt_4_6 );
 
-      stream << (qulonglong)pendingNotifications.count();
+      stream << (qulonglong)(pipeline.count() + pendingNotifications.count());
+
+      for ( int i = 0; i < pipeline.count(); ++i ) {
+        const NotificationMessage msg = pipeline.at( i );
+        addToStream( stream, msg );
+      }
 
       for ( int i = 0; i < pendingNotifications.count(); ++i ) {
         const NotificationMessage msg = pendingNotifications.at( i );
-
-        stream << msg.sessionId();
-        stream << msg.type();
-        stream << msg.operation();
-        stream << msg.uid();
-        stream << msg.remoteId();
-        stream << msg.resource();
-        stream << msg.parentCollection();
-        stream << msg.parentDestCollection();
-        stream << msg.mimeType();
-        stream << msg.itemParts();
+        addToStream( stream, msg );
       }
-
-      file.close();
     }
 };
 
