@@ -318,7 +318,7 @@ void CollectionStatisticsDelegate::paint( QPainter *painter,
     return;
   }
 
-  painter->drawText( textRect, option4.displayAlignment, text );
+  painter->drawText( textRect, option4.displayAlignment | Qt::AlignVCenter, text );
 }
 
 #include "collectionstatisticsdelegate.moc"
