@@ -2650,6 +2650,11 @@ bool ICalFormatImpl::populate( const Calendar::Ptr &cal, icalcomponent *calendar
     if ( event ) {
       Event::Ptr old = cal->event( event->uid(), event->recurrenceId() );
       if ( old ) {
+        if ( old->uid().isEmpty() ) {
+          qWarning() << "Skipping invalid VEVENT";
+          c = icalcomponent_get_next_component( calendar, ICAL_VEVENT_COMPONENT );
+          continue;
+        }
           qDebug() << "OLD EVENT" << old->uid();
         if ( deleted ) {
           cal->deleteEvent( old ); // move old to deleted
@@ -2781,11 +2786,11 @@ icalcomponent *ICalFormatImpl::createScheduleComponent( const IncidenceBase::Ptr
     const KDateTime kd1 = incidence->dateTime( IncidenceBase::RoleStartTimeZone );
     const KDateTime kd2 = incidence->dateTime( IncidenceBase::RoleEndTimeZone );
 
-    if ( kd1.isValid() ) {
+    if ( kd1.isValid() && kd1.timeZone() != KTimeZone::utc() ) {
       zones.add( ICalTimeZone( kd1.timeZone() ) );
     }
 
-    if ( kd2.isValid() ) {
+    if ( kd2.isValid() && kd2.timeZone() != KTimeZone::utc() ) {
       zones.add( ICalTimeZone( kd2.timeZone() ) );
     }
 
